@@ -5,16 +5,14 @@ use strict ;
 # The default J2SDK to use for Inline::Java. You can change
 # it if this value becomes invalid.
 sub Inline::Java::get_default_j2sdk {
-	return '/usr/lib/jvm/java-7-openjdk' ;
+	return '/usr/lib/jvm/java-11-openjdk' ;
 }
 1 ;
 
 
 sub Inline::Java::get_default_j2sdk_so_dirs {
 	return (
-		'/usr/lib/jvm/java-7-openjdk/jre/lib/aarch64/jli',
-		'/usr/lib/jvm/java-7-openjdk/jre/lib/aarch64/server',
-		'/usr/lib/jvm/java-7-openjdk/jre/lib/aarch64',
+		'/usr/lib/jvm/java-11-openjdk/lib/server',
 	) ;
 }
 
